# Contributing to EXOTIC

EXOTIC is an open source project that welcomes contributions. Please fork the repository and submit a pull request to 
the develop branch for your addition(s) to be reviewed. 